# This file is MACHINE GENERATED! Do not edit.
# Generated by: tensorflow/python/tools/api/generator/create_python_api.py script.
"""Public API for tf.lite.experimental namespace.
"""

from __future__ import print_function as _print_function

import sys as _sys

from . import nn
from tensorflow.lite.python.lite import convert_op_hints_to_stubs
from tensorflow.lite.python.lite import get_potentially_supported_ops
from tensorflow.lite.python.lite import load_delegate

del _print_function



# This file is MACHINE GENERATED! Do not edit.
# Generated by: tensorflow/python/tools/api/generator/create_python_api.py script.
"""Public API for tf.config.experimental namespace.
"""

from __future__ import print_function as _print_function

import sys as _sys

from tensorflow.python.eager.context import VirtualDeviceConfiguration
from tensorflow.python.framework.config import get_device_policy
from tensorflow.python.framework.config import get_memory_growth
from tensorflow.python.framework.config import get_synchronous_execution
from tensorflow.python.framework.config import get_virtual_device_configuration
from tensorflow.python.framework.config import get_visible_devices
from tensorflow.python.framework.config import list_logical_devices
from tensorflow.python.framework.config import list_physical_devices
from tensorflow.python.framework.config import set_device_policy
from tensorflow.python.framework.config import set_memory_growth
from tensorflow.python.framework.config import set_synchronous_execution
from tensorflow.python.framework.config import set_virtual_device_configuration
from tensorflow.python.framework.config import set_visible_devices

del _print_function
